@@ -339,7 +339,6 @@ public:
     bool test_debug_info();
     bool test_inspect_variables();
     bool test_variables();
-    bool test_next();
     void shutdown();
 
 private:
@@ -376,13 +375,12 @@ bool debugger_client::test_init()
 {
     m_client.send_on_control("debug_request", make_init_request());
     nl::json rep = m_client.receive_on_control();
-    return rep["content"]["type"] == "response";
+    return rep["content"]["success"].get<bool>();
 }
 
 bool debugger_client::test_disconnect()
 {
-    m_client.send_on_control("debug_request", make_init_request());
-    m_client.receive_on_control();
+    attach();
     m_client.send_on_control("debug_request", make_disconnect_request(3));
     nl::json rep = m_client.receive_on_control();
     return rep["content"]["type"] == "response";
@@ -515,7 +513,9 @@ bool debugger_client::test_external_next_continue()
     // We set 2 breakpoints on line 3 and 5 of external_code.py
     set_external_breakpoints();
     m_client.send_on_control("debug_request", make_configuration_done_request(5));
+    std::cout << "Configuration done sent" << std::endl;
     m_client.receive_on_control();
+    std::cout << "Configuration done received" << std::endl;
 
     m_client.send_on_shell("execute_request", make_execute_request(make_external_invoker_code()));
     return next_continue_common();
@@ -726,47 +726,6 @@ bool debugger_client::test_variables()
     return res;
 }
 
-bool debugger_client::test_next()
-{
-    attach();
-    {
-        m_client.send_on_control("debug_request", make_dump_cell_request(4, make_code()));
-        nl::json res = m_client.receive_on_control();
-        std::string path = res["content"]["body"]["sourcePath"].get<std::string>();
-        m_client.send_on_control("debug_request", make_breakpoint_request(4, path, 2, 3));
-        m_client.receive_on_control();
-    }
-
-    m_client.send_on_control("debug_request", make_configuration_done_request(5));
-    m_client.receive_on_control();
-
-    for(int j = 0; j < 3; ++j)
-    {
-        m_client.send_on_shell("execute_request", make_execute_request(make_code()));
-
-        int seq = 6;
-        int nb_next = 3;
-
-        for(int i = 0; i < nb_next; ++i)
-        {
-            nl::json ev = m_client.wait_for_debug_event("stopped");
-            m_client.send_on_control("debug_request", make_stacktrace_request(seq, 1));
-            ++seq;
-            nl::json json = m_client.receive_on_control();
-            next(seq);
-        }
-
-        m_client.send_on_control("debug_request", make_stacktrace_request(seq, 1));
-        ++seq;
-        nl::json json = m_client.receive_on_control();
-
-        nl::json rep = m_client.receive_on_shell();
-        bool res = rep["content"]["status"] == "ok";
-    }
-
-    return true;
-}
-
 void debugger_client::shutdown()
 {
     m_client.send_on_control("shutdown_request", make_shutdown_request());
@@ -776,7 +735,13 @@ void debugger_client::shutdown()
 nl::json debugger_client::attach()
 {
     m_client.send_on_control("debug_request", make_init_request());
-    m_client.receive_on_control();
+    nl::json rep = m_client.receive_on_control();
+    if (!rep["content"]["success"].get<bool>())
+    {
+        shutdown();
+        std::this_thread::sleep_for(2s);
+        throw std::runtime_error("Could not initialize debugger, exiting");
+    }
     m_client.send_on_control("debug_request", make_attach_request(3));
     return m_client.receive_on_control();
 }
@@ -936,6 +901,21 @@ TEST(debugger, disconnect)
     }
 }
 
+TEST(debugger, attach)
+{
+    start_kernel();
+    start_timer();
+    zmq::context_t context;
+    {
+        debugger_client deb(context, KERNEL_JSON, "debugger_attach.log");
+        bool res = deb.test_attach();
+        deb.shutdown();
+        std::this_thread::sleep_for(2s);
+        EXPECT_TRUE(res);
+        notify_done();
+    }
+}
+
 TEST(debugger, multisession)
 {
     start_kernel();
@@ -954,22 +934,6 @@ TEST(debugger, multisession)
     }
 }
 
-TEST(debugger, attach)
-{
-    start_kernel();
-    start_timer();
-    zmq::context_t context;
-    {
-        debugger_client deb(context, KERNEL_JSON, "debugger_attach.log");
-        bool res = deb.test_attach();
-        deb.shutdown();
-        std::this_thread::sleep_for(2s);
-        EXPECT_TRUE(res);
-        notify_done();
-    }
-}
-
-#if PY_MAJOR_VERSION == 3
 TEST(debugger, set_external_breakpoints)
 {
     start_kernel();
@@ -1120,20 +1084,3 @@ TEST(debugger, variables)
     }
 }
 
-TEST(debugger, next)
-{
-    start_kernel();
-    start_timer();
-    zmq::context_t context;
-    {
-        debugger_client deb(context, KERNEL_JSON, "debugger_debug_info.log");
-        bool res = deb.test_next();
-        deb.shutdown();
-        std::this_thread::sleep_for(2s);
-        EXPECT_TRUE(res);
-        notify_done();
-    }
-}
-
-#endif
-
